Package: gwascat
Title: representing and modeling data in the EMBL-EBI GWAS catalog
Version: 2.44.0
Author: VJ Carey <stvjc@channing.harvard.edu>
Description: Represent and model data in the EMBL-EBI GWAS catalog.
Enhances: SNPlocs.Hsapiens.dbSNP144.GRCh37
Depends: R (>= 4.1.0), methods
Imports: S4Vectors (>= 0.9.25), IRanges, Seqinfo, GenomeInfoDb,
        GenomicRanges (>= 1.29.6), GenomicFeatures, readr, Biostrings,
        AnnotationDbi, BiocFileCache, snpStats, VariantAnnotation,
        AnnotationHub, data.table, tibble
Suggests: DO.db, DT, knitr, RBGL, testthat, rmarkdown, dplyr, Gviz,
        Rsamtools, rtracklayer, graph, ggbio, DelayedArray,
        TxDb.Hsapiens.UCSC.hg19.knownGene, org.Hs.eg.db, BiocStyle
VignetteBuilder: knitr
Maintainer: VJ Carey <stvjc@channing.harvard.edu>
License: Artistic-2.0
LazyData: no
biocViews: Genetics
RoxygenNote: 7.3.3
Encoding: UTF-8
git_url: https://git.bioconductor.org/packages/gwascat
git_branch: RELEASE_3_23
git_last_commit: d06d166
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:32:47 UTC; biocbuild
