# Generated by roxygen2: do not edit by hand

export(as_GRanges)
export(bindcadd_snv)
export(fixsnps)
export(getRsids)
export(getTraits)
export(get_cached_gwascat)
export(gwascat_from_AHub)
export(gwcat_snapshot)
export(gwcex2gviz)
export(ldtagr)
export(locs4trait)
export(makeCurrentGwascat)
export(obo2graphNEL)
export(process_gwas_dataframe)
export(riskyAlleleCount)
export(subsetByChromosome)
export(subsetByTraits)
export(topTraits)
export(traitsManh)
exportClasses(gwaswloc)
exportMethods("[")
exportMethods(getRsids)
exportMethods(getTraits)
exportMethods(subsetByChromosome)
exportMethods(subsetByTraits)
import(BiocFileCache)
import(S4Vectors)
import(VariantAnnotation)
import(methods)
import(snpStats)
import(tibble)
importClassesFrom(GenomicRanges,GRanges)
importClassesFrom(IRanges,IRanges)
importFrom(AnnotationDbi,mapIds)
importFrom(GenomeInfoDb,"seqlevelsStyle<-")
importFrom(GenomeInfoDb,seqlevelsStyle)
importFrom(GenomicFeatures,exons)
importFrom(GenomicRanges,GRanges)
importFrom(IRanges,IRanges)
importFrom(IRanges,overlapsAny)
importFrom(S4Vectors,"mcols<-")
importFrom(S4Vectors,"metadata<-")
importFrom(S4Vectors,mcols)
importFrom(S4Vectors,metadata)
importFrom(Seqinfo,"genome<-")
importFrom(Seqinfo,"seqinfo<-")
importFrom(Seqinfo,"seqlengths<-")
importFrom(Seqinfo,"seqlevels<-")
importFrom(Seqinfo,genome)
importFrom(Seqinfo,seqinfo)
importFrom(Seqinfo,seqlengths)
importFrom(Seqinfo,seqlevels)
importFrom(Seqinfo,seqnames)
importFrom(data.table,fread)
importFrom(utils,data)
importFrom(utils,download.file)
importFrom(utils,read.delim)
importFrom(utils,sessionInfo)
