
#' seqinfo for GRCh37
#' @docType data
#' @format Seqinfo instance
#' @examples
#' si.hs.37
"si.hs.37" 

#' a legacy representation of EBI's GWAS catalog with loci annotated to positions on GRCh37
#' @docType data
#' @format gwaswloc instance
"ebicat37" 

#' a legacy representation of EBI's GWAS catalog with loci annotated to positions on GRCh37 but
#' UCSC chromosome names
#' @docType data
"ebicat37UCSC" 

#' a legacy representation of EBI's GWAS catalog with loci annotated to positions on GRCh37
#' @docType data
#' @format gwaswloc instance
"ebicat_b37" 

#' a legacy representation of EBI's GWAS catalog with loci annotated to positions on GRCh38
#' @docType data
#' @format gwaswloc instance
"ebicat_b38"

