% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{locon6}
\alias{locon6}
\title{location data for 10000 SNP}
\format{
data.frame, coordinates are hg19
}
\usage{
data(locon6)
}
\description{
location data for 10000 SNP
}
\keyword{datasets}
