% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{si.hs.37}
\alias{si.hs.37}
\title{Seqinfo for GRCh37}
\format{
Seqinfo instance
}
\usage{
data(si.hs.37)
}
\description{
Seqinfo for GRCh37
}
\keyword{datasets}
