% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{g17SM}
\alias{g17SM}
\title{SnpMatrix instance from chr17}
\format{
snpStats SnpMatrix instance
}
\usage{
data(g17SM)
}
\description{
SnpMatrix instance from chr17
}
\keyword{datasets}
