% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/classes.R
\name{getRsids}
\alias{getRsids}
\title{generic snp name retrieval}
\usage{
getRsids(x)
}
\arguments{
\item{x}{gwaswloc}
}
\description{
generic snp name retrieval
}
