% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/classes.R
\name{getTraits}
\alias{getTraits}
\title{generic trait retrieval}
\usage{
getTraits(x)
}
\arguments{
\item{x}{gwaswloc}
}
\description{
generic trait retrieval
}
