% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/classes.R
\docType{class}
\name{gwaswloc-class}
\alias{gwaswloc-class}
\title{container for gwas hit data and GRanges for addresses}
\description{
container for gwas hit data and GRanges for addresses
}
